@@ -10,20 +10,25 @@ except:
     from yaml import Loader
 from . import licenses
 
-__version__ = '0.0.4'
+__version__ = '0.0.5'
 
 
-class DapFileError(Exception):
+class DapError(Exception):
+    '''Mother of all dap related exceptions'''
+    pass
+
+
+class DapFileError(DapError):
     '''Exception that indicates something wrong with dap file'''
     pass
 
 
-class DapMetaError(Exception):
+class DapMetaError(DapError):
     '''Exception that indicates something wrong with dap's metadata'''
     pass
 
 
-class DapInvalid(Exception):
+class DapInvalid(DapError):
     '''Exception that indicates invalid dap'''
     pass
 
@@ -221,9 +226,9 @@ class Dap(object):
             name = self.meta['package_name']
 
             dirs = re.compile('^' + dirname + '((assistants(/(crt|mod|prep|task))?|snippets)(/' +
-                              name + ')?|icons(/' + name + ')?|files|(files/(crt|mod|prep|task|snippets)|doc)(/' + name + '(/.+)?)?)$')
+                              name + ')?|icons(/(crt|mod|prep|task|snippets)(/' + name + ')?)?|files|(files/(crt|mod|prep|task|snippets)|doc)(/' + name + '(/.+)?)?)$')
             regs = re.compile('^' + dirname + '((assistants(/(crt|mod|prep|task))|snippets)/' +
-                              name + r'(/[^/]+)?\.yaml|icons/' + name + r'(/[^/]+)?\.(' +
+                              name + r'(/[^/]+)?\.yaml|icons/(crt|mod|prep|task|snippets)/' + name + r'(/[^/]+)?\.(' +
                               Dap._icons + ')|(files/(crt|mod|prep|task|snippets)|doc)/' + name + '/.+)$')
 
             remove = []
@@ -252,10 +257,9 @@ class Dap(object):
                 if f.startswith(os.path.join(dirname, 'icons/')):
                     # name without extension and dirname/icons/
                     icons.append('.'.join(f[len(os.path.join(dirname, 'icons/')):].split('.')[:-1]))
-                for t in ['assistants/' + t for t in 'crt mod prep task'.split()] + ['snippets']:
-                    if f.startswith(os.path.join(dirname, t, '')):
-                        # extension is .yaml only, so we don't need to split
-                        assistants.add(f[len(os.path.join(dirname, t, '')):-len('.yaml')])
+                if f.startswith(os.path.join(dirname, 'assistants/')):
+                    # extension is .yaml only, so we don't need to split and join
+                    assistants.add(f[len(os.path.join(dirname, 'assistants/')):-len('.yaml')])
         duplicates = set([x for x in icons if icons.count(x) > 1])
         for d in duplicates:
             self._report_problem('Duplicate icon for ' + f, logging.WARNING)
